@@ -70,7 +70,7 @@ def test_module(mod):
                       'ClassWithUndocumentedMembers', 'ClassWithGetterSetter',
                       'ClassWithDoubleQuotedString', 'ClassWithDummyArguments',
                       'ClassWithStrings', 'ClassWithFunctionArguments', 'ClassWithMethodsWithSpaces',
-                      'ClassContainingParfor', 'ClassWithStringEllipsis', 'ClassLongProperty', 'ClassWithGetMethod'}
+                      'ClassContainingParfor', 'ClassWithStringEllipsis', 'ClassLongProperty', 'ClassWithGetMethod', 'ClassWithLongPropertyDocstrings', 'ClassWithLongPropertyTrailingEmptyDocstrings'}
     assert all_items == expected_items
     assert mod.getter('__name__') in modules
 
@@ -235,7 +235,7 @@ def test_class_with_get_method(mod):
     assert the_class.docstring == " Class with a method named get\n"
     the_method = the_class.getter('get')
     assert isinstance(the_method, doc.MatMethod)
-    assert the_method.getter('__name__') == 'get'        
+    assert the_method.getter('__name__') == 'get'
     assert the_method.retv == ['varargout']
     assert the_method.docstring.startswith(" Gets the numbers 1-n and fills in the outputs with them")
 
